@@ -1,4 +1,4 @@
-__version__ = '0.5.2'
+__version__ = '0.5.4'
 
 from symgroupy import symgrouplib
 import numpy as np
@@ -44,19 +44,17 @@ class Symgroupy:
         operation = group[0].lower().encode('ascii')
         try:
             operation_axis = int(group[1:])
-        except IndexError:
-            operation_axis = 1
         except ValueError:
-            if operation in [b'i', b'r', b'e']:  # accepted operations
+            if group in ['cs', 'ci']:
+                operation = {'cs': 'r', 'ci': 'i'}[group]
+                operation_axis = -1
+            elif operation in [b'i', b'r', b'e']:  # accepted operations
                 operation_axis = 0
             else:
                 raise Exception('Wrong symmetry label')
 
         if center is None:
-            fixcenter = False
-            center= [0, 0, 0]
-        else:
-            fixcenter = True
+            center = np.average(coordinates, axis=0)
 
         if connectivity is None:       # not use connectivity
             connect_type = 0
@@ -79,7 +77,7 @@ class Symgroupy:
         coordinates = np.ascontiguousarray(coordinates)
 
         outputs = symgrouplib.symgroup(coordinates, multi, labels, central_atom, operation,
-                                       operation_axis, fixcenter, center, connect_type, conv,
+                                       operation_axis, True, center, connect_type, conv,
                                        connect_thresh, fix_permutation, permutation)
 
         # Reorganize outputs
@@ -90,6 +88,12 @@ class Symgroupy:
         self._reference_axis = outputs[4]
         self._csm_multi = outputs[5][:multi]
         self._axis_multi = outputs[6][:multi,:]
+        self._center = center
+
+        # handle ci and cs groups
+        if operation_axis == -1:
+            self._csm = self._csm/2
+            self._csm_multi = self._csm_multi/2
 
     @property
     def csm(self):
@@ -119,6 +123,9 @@ class Symgroupy:
     def axis_multi(self):
         return self._axis_multi
 
+    @property
+    def center(self):
+        return self._center
 
 if __name__ == '__main__':
 
@@ -128,13 +135,15 @@ if __name__ == '__main__':
                         [0.19731029,    0.22551373,   -0.87365150],
                         [-1.22936255,   -0.27887127,    0.00000000]]
 
-
-# Symmetry point groups available:
+    # Symmetry operations available:
     # e: identity
     # i: inversion
     # r: reflection
+    # Symmetry point groups available:
     # cn: rotation (n:order)
     # sn: improper rotation (n:order)
+    # ci
+    # cs
 
     bonds = [(1, 2), (1, 3), (1, 4), (1, 5)]  # pairs of atoms
 
@@ -158,6 +167,7 @@ if __name__ == '__main__':
     print(fen4.cms_multi)
     print('multi axis')
     print(fen4.axis_multi)
+    print('center', fen4.center)
 
     print('---')
 
